# -*- coding:utf-8 -*-
"Yet Another DI Container"

from yadic.container import Injectable, Container

